@@ -1,4 +1,4 @@
-from importlib.machinery import SourceFileLoader
+from pydoc import importfile  
 import os
 import sys
 import argparse
@@ -20,10 +20,8 @@ def parse_options(args_):
 
 def import_files(file_):
     file_= file_.replace('//', '/').replace('\\', '/')
-    dir_, file_ = file_.rsplit('/', 1)
-    file_ = file_.replace('.py', '')
 
-    x = SourceFileLoader(file_, dir_).load_module()
+    module = importfile(os.getcwd() + '/' + file_)
 
 def test_files(opts, path):
     smoke_test_done = False
